@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2018 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -141,6 +141,26 @@ int any_f_new_from_file_(int *fid, int *gid);
 int any_f_new_from_file__(int *fid, int *gid);
 int any_f_new_from_file(int *fid, int *gid);
 
+int any_f_scan_file_(int* fid,int* n);
+int any_f_scan_file__(int* fid,int* n);
+int any_f_scan_file(int* fid,int* n);
+
+int any_f_new_from_scanned_file_(int* fid,int* msgid,int* gid);
+int any_f_new_from_scanned_file__(int* fid,int* msgid,int* gid);
+int any_f_new_from_scanned_file(int* fid,int* msgid,int* gid);
+
+int any_f_load_all_from_file_(int* fid,int* n);
+int any_f_load_all_from_file__(int* fid,int* n);
+int any_f_load_all_from_file(int* fid,int* n);
+
+int any_f_new_from_loaded_(int* msgid,int* gid);
+int any_f_new_from_loaded__(int* msgid,int* gid);
+int any_f_new_from_loaded(int* msgid,int* gid);
+
+int codes_f_clear_loaded_from_file_();
+int codes_f_clear_loaded_from_file__();
+int codes_f_clear_loaded_from_file();
+
 int grib_f_new_from_file_(int *fid, int *gid);
 int grib_f_new_from_file__(int *fid, int *gid);
 int grib_f_new_from_file(int *fid, int *gid);
