@@ -173,7 +173,7 @@ void grib_hash_array_value_delete(grib_context *c, grib_hash_array_value *v);
 bufr_descriptor *grib_bufr_descriptor_new(grib_accessor *tables_accessor, int code, int *err);
 bufr_descriptor *grib_bufr_descriptor_clone(bufr_descriptor *d);
 int grib_bufr_descriptor_set_code(grib_accessor *tables_accessor, int code, bufr_descriptor *v);
-void grib_bufr_descriptor_set_reference(bufr_descriptor *v, double reference);
+void grib_bufr_descriptor_set_reference(bufr_descriptor *v, long reference);
 void grib_bufr_descriptor_set_width(bufr_descriptor *v, long width);
 void grib_bufr_descriptor_set_scale(bufr_descriptor *v, long scale);
 int grib_bufr_descriptor_can_be_missing(bufr_descriptor *v);
@@ -997,12 +997,15 @@ void grib_context_set_handle_file_count(grib_context *c, int new_count);
 void grib_context_set_handle_total_count(grib_context *c, int new_count);
 void grib_context_increment_handle_file_count(grib_context *c);
 void grib_context_increment_handle_total_count(grib_context *c);
+bufr_descriptors_array* grib_context_expanded_descriptors_list_get(grib_context* c,const char* key,long* u,size_t size);
+void grib_context_expanded_descriptors_list_push(grib_context* c,const char* key,bufr_descriptors_array* expanded,bufr_descriptors_array* unexpanded);
 void codes_set_codes_assertion_failed_proc(codes_assertion_failed_proc proc);
 void codes_assertion_failed(const char *message, const char *file, int line);
 
 /* grib_date.c */
 int grib_julian_to_datetime(double jd, long *year, long *month, long *day, long *hour, long *minute, long *second);
 int grib_datetime_to_julian(long year, long month, long day, long hour, long minute, long second, double *jd);
+int grib_datetime_to_julian_d(long year,long month,long day,long hour,long minute,double second, double* jd);
 long grib_julian_to_date(long jdate);
 long grib_date_to_julian(long ddate);
 
@@ -1098,7 +1101,7 @@ void grib_math_delete(grib_context *c, grib_math *m);
 grib_math *grib_math_new(grib_context *c, const char *formula, int *err);
 
 /* grib_hash_keys.c */
-struct grib_keys_hash *grib_keys_hash_get(const char *str, unsigned int len);
+const struct grib_keys_hash *grib_keys_hash_get(const char *str, unsigned int len);
 grib_itrie *grib_hash_keys_new(grib_context *c, int *count);
 void grib_hash_keys_delete(grib_itrie *t);
 int grib_hash_keys_get_id(grib_itrie *t, const char *key);
